@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use 5.010;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 our $PANDOC_VERSION;   # a string like '1.16'
 $PANDOC_VERSION ||= $ENV{PANDOC_VERSION};
@@ -37,6 +37,7 @@ our %ELEMENTS = (
     Cite        => [ Inline => qw(citations content) ],
     Code        => [ Inline => qw(attr content) ],
     Space       => ['Inline'],
+    SoftBreak   => ['Inline'],
     LineBreak   => ['Inline'],
     Math        => [ Inline => qw(type content) ],
     RawInline   => [ Inline => qw(format content) ],
@@ -162,7 +163,7 @@ sub pandoc_json($) {
         my $class = 'Pandoc::Document::' . $_[0]->{t};
         if ( 'MetaMap' eq $_[0]->{t} ) {
             for my $v ( values %{ $_[0]->{c} } ) {
-                $v = $_[1]->($v);
+                $_[1]->($v, $_[1]);
             }
         }
         return $class->new_from_ast($_[0])
@@ -239,16 +240,16 @@ sub pandoc_json($) {
     sub string {
 
         # TODO: fix issue #4 to avoid this duplication
-        if ( $_[0]->name =~ /^(Str|Code|Math)$/ ) {
+        if ( $_[0]->name =~ /^(Str|Code|Math|MetaString)$/ ) {
             return $_[0]->content;
         }
-        elsif ( $_[0]->name =~ /^(LineBreak|Space)$/ ) {
+        elsif ( $_[0]->name =~ /^(LineBreak|Space|MetaString)$/ ) {
             return ' ';
         }
         join '', @{
             $_[0]->query(
                 {
-                    'Str|Code|Math'   => sub { $_->content },
+                    'Str|Code|Math|MetaString'   => sub { $_->content },
                     'LineBreak|Space' => sub { ' ' },
                 }
             );
@@ -756,6 +757,12 @@ Small caps text, a list of L<inlines|/INLINE ELEMENTS> (C<content>).
 
     SmallCaps [ @inlines ]
 
+=head3 SoftBreak
+
+Soft line break
+
+    SoftBreak
+
 =head3 Space
 
 Inter-word space
@@ -862,7 +869,7 @@ L<Pandoc> implements a wrapper around the pandoc executable.
 
 L<Text.Pandoc.Definition|https://hackage.haskell.org/package/pandoc-types/docs/Text-Pandoc-Definition.html>
 contains the original definition of Pandoc document data structure in Haskell.
-This module version was last aligned with pandoc-types-1.12.4.
+This module version was last aligned with pandoc-types-1.16.1.
 
 =head1 AUTHOR
 
